(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    101196,       2840]
NotebookOptionsPosition[     83735,       2528]
NotebookOutlinePosition[     84073,       2543]
CellTagsIndexPosition[     84030,       2540]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
This Notebook contains the proofs of all the results in the paper
\"Inequalities Involving Gergonne and Nagel Cevians\" by Stanley Rabinowitz,
submitted to the International Journal of Computer Discovered Mathematics 
(http : // www.journal - 1. eu/) on March 2021.
 
This Notebook is Copyright \[Copyright] March 2021 by Stanley Rabinowitz \
(stan.rabinowitz@comcast.net) and is published with open access. This \
Notebook is distributed under the terms of the Creative Commons Attribution \
License which permits any use, distribution, and reproduction in any medium, \
provided the original author and the source are credited.\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.823362867312365*^9, 3.823362892123764*^9}, {
  3.823362940554699*^9, 3.823363012293025*^9}, {3.823423241988761*^9, 
  3.8234232521964083`*^9}},ExpressionUUID->"64fd82a1-8e0f-43f3-86ab-\
455e67903074"],

Cell[CellGroupData[{

Cell["Cevian Lengths", "Chapter",
 CellChangeTimes->{{3.823261153725445*^9, 
  3.823261163305024*^9}},ExpressionUUID->"0a4874d9-3130-4a27-a30f-\
2e8f0459f162"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Function", " ", "to", " ", "do", " ", "a", " ", "cyclic", " ", "sum"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"csum", "[", "expr_", "]"}], ":=", 
    RowBox[{"expr", "+", 
     RowBox[{"(", 
      RowBox[{"expr", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "\[Rule]", "b"}], ",", 
         RowBox[{"b", "\[Rule]", "c"}], ",", 
         RowBox[{"c", "\[Rule]", "a"}], ",", 
         RowBox[{"A", "\[Rule]", "B"}], ",", 
         RowBox[{"B", "\[Rule]", "C"}], ",", 
         RowBox[{"C", "\[Rule]", "A"}]}], "}"}]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{"expr", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "\[Rule]", "c"}], ",", 
         RowBox[{"b", "\[Rule]", "a"}], ",", 
         RowBox[{"c", "\[Rule]", "b"}], ",", 
         RowBox[{"A", "\[Rule]", "C"}], ",", 
         RowBox[{"B", "\[Rule]", "A"}], ",", 
         RowBox[{"C", "\[Rule]", "B"}]}], "}"}]}], ")"}]}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.823363044510294*^9, 3.823363048221489*^9}, {
  3.82336314448731*^9, 3.823363168806435*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"dd3203e7-630d-4de8-a023-9b29d99ff1a6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "semiperimeter", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"s", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.823363172093875*^9, 3.8233631771497183`*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"1fa983dd-8923-4f11-b5c0-a4881ad377ce"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Length", " ", "of", " ", "Gergonne", " ", "cevian"}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{"ga", "=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", "-", "a"}], ")"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", "*", "s"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"b", "-", "c"}], ")"}], "^", "2"}]}], ")"}], "/", "a"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.823011245873302*^9, 3.82301126759338*^9}, {
  3.823011428362597*^9, 3.8230114423214808`*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"35752e91-8d8c-4ddf-8db4-4082c0e63eb2"],

Cell[BoxData[
 SqrtBox[
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "-", "c"}], ")"}], "2"]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]}], ")"}]}], 
   "a"]]], "Output",
 CellChangeTimes->{3.823011268902685*^9, 3.823013381033493*^9, 
  3.823177653873517*^9, 3.823260921977153*^9, 3.823334488181952*^9, 
  3.823363306203397*^9, 3.823364941134186*^9, 3.823418596120927*^9, 
  3.823424401771804*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"d357b4bf-7cfc-4eca-9bef-9c1e6cc23d8f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Length", " ", "of", " ", "Nagel", " ", "cevian"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"SB", "=", 
     RowBox[{"s", "-", "b"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SC", "=", 
     RowBox[{"s", "-", "c"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"na", "=", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c", "^", "2"}], "SB"}], "+", 
         RowBox[{
          RowBox[{"b", "^", "2"}], "SC"}], "-", 
         RowBox[{"a", "*", "SB", "*", "SC"}]}], ")"}], "/", "a"}], "//", 
      "Simplify"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.823182617171549*^9, 3.823182626035049*^9}, {
   3.8231828261482267`*^9, 3.8231829070359697`*^9}, {3.8231829645099077`*^9, 
   3.823182974676816*^9}, 3.823186673854877*^9},
 CellLabel->"In[67]:=",ExpressionUUID->"f5bbd733-be0d-4394-900c-0272bd8fce2e"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SqrtBox[
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "3"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], "+", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "a"]]}]], "Output",
 CellChangeTimes->{{3.8231828986684437`*^9, 3.823182907913637*^9}, 
   3.823182975619115*^9, 3.823186674576766*^9, 3.82326092202923*^9, 
   3.823334488240184*^9, 3.823363306251032*^9, 3.8233649411544533`*^9, 
   3.823418596176261*^9, 3.823424401777652*^9},
 CellLabel->"Out[69]=",ExpressionUUID->"844f63f2-88db-4304-8f73-e235a20e268c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Length", " ", "of", " ", "median"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"ma", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"b", "^", "2"}]}], "+", 
      RowBox[{"2", 
       RowBox[{"c", "^", "2"}]}], "-", 
      RowBox[{"a", "^", "2"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8230114464660482`*^9, 3.823011514521997*^9}, {
  3.8231832084138603`*^9, 3.823183208684802*^9}},
 CellLabel->"In[70]:=",ExpressionUUID->"7deb680b-02ca-4abb-9b41-20c7ceb43934"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SqrtBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["c", "2"]}]}]]}]], "Output",
 CellChangeTimes->{3.823011516035925*^9, 3.823013383806284*^9, 
  3.8231776539288588`*^9, 3.823260922037682*^9, 3.82333448824702*^9, 
  3.8233633062582407`*^9, 3.823364941160645*^9, 3.823418596182559*^9, 
  3.823424401784214*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"4ea86878-009a-4357-8e3f-65daff0ecad4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Length", " ", "of", " ", "angle", " ", "bisector"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"wa", "=", 
   RowBox[{"2", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"b", "*", "c", "*", "s", 
       RowBox[{"(", 
        RowBox[{"s", "-", "a"}], ")"}]}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"b", "+", "c"}], ")"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.8230116940425*^9, 3.823011739986187*^9}, 
   3.823012883790347*^9, 3.823014507468389*^9},
 CellLabel->"In[71]:=",ExpressionUUID->"aa36aeb7-fc56-4cd4-a6c0-44146bf44443"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SqrtBox["2"], " ", 
   SqrtBox[
    RowBox[{"b", " ", "c", " ", 
     RowBox[{"(", 
      RowBox[{"a", "+", "b", "+", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]}], ")"}]}]]}], 
  RowBox[{"b", "+", "c"}]]], "Output",
 CellChangeTimes->{3.823011741032992*^9, 3.823013386230135*^9, 
  3.823014507926485*^9, 3.823177653937846*^9, 3.823260922092412*^9, 
  3.823334488304439*^9, 3.823363306306237*^9, 3.823364941166848*^9, 
  3.823418596233136*^9, 3.823424401830722*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"77db841f-e9cd-4324-87ea-9a5fdf4bc1fb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "area", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"K", "=", 
   RowBox[{
    RowBox[{"Sqrt", "[", 
     RowBox[{"s", 
      RowBox[{"(", 
       RowBox[{"s", "-", "a"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"s", "-", "b"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"s", "-", "c"}], ")"}]}], "]"}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.82301286408578*^9, 3.823012890756988*^9}, {
  3.8233630729191923`*^9, 3.823363075805375*^9}},
 CellLabel->"In[72]:=",ExpressionUUID->"56f18171-bcbe-483d-a943-cc542dd682e7"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  SqrtBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "4"]}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], "2"], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]}]]}]], "Output",
 CellChangeTimes->{{3.823012881181046*^9, 3.823012891833088*^9}, 
   3.8230133896555862`*^9, 3.8231776539928837`*^9, 3.823260922100263*^9, 
   3.823334488311584*^9, 3.823363076676787*^9, 3.823363306313521*^9, 
   3.823364941187447*^9, 3.823418596282943*^9, 3.823424401836967*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"aadbe506-da57-4e68-ba5e-617ae7e9309d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Length", " ", "of", " ", "altitude"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"ha", "=", 
   RowBox[{
    RowBox[{"2", 
     RowBox[{"K", "/", "a"}]}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.823012894173347*^9, 3.823012923692759*^9}, {
  3.823363085654559*^9, 3.823363088269417*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"f972d136-f2d8-4809-a49a-befbb2b2f27a"],

Cell[BoxData[
 FractionBox[
  SqrtBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "4"]}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], "2"], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]}]], 
  RowBox[{"2", " ", "a"}]]], "Output",
 CellChangeTimes->{3.823012924851144*^9, 3.823013395000938*^9, 
  3.8231776540013323`*^9, 3.8232609221538057`*^9, 3.8233344883696737`*^9, 
  3.823363089166419*^9, 3.8233633063634167`*^9, 3.823364941193894*^9, 
  3.8234185962918386`*^9, 3.823424401842681*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"2f93e7d4-b72d-4e47-9ede-55087ee743f5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"length", " ", "of", " ", "inradius"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"r", "=", 
   RowBox[{
    RowBox[{"K", "/", "s"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.823012940917379*^9, 3.8230129580209627`*^9}, {
  3.823363094070668*^9, 3.823363096733367*^9}},
 CellLabel->"In[74]:=",ExpressionUUID->"edf11d8e-1c85-4cfe-a5b5-4f1597686d98"],

Cell[BoxData[
 FractionBox[
  SqrtBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "4"]}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], "2"], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]}]], 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]], "Output",
 CellChangeTimes->{3.823012958655685*^9, 3.823013397885386*^9, 
  3.823177654058522*^9, 3.823260922161765*^9, 3.82333448837649*^9, 
  3.823363097724759*^9, 3.8233633063707037`*^9, 3.82336494119983*^9, 
  3.823418596339985*^9, 3.823424401850062*^9},
 CellLabel->"Out[74]=",ExpressionUUID->"ebc697fb-037c-4b2f-a81a-bbc3463a4141"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"length", " ", "of", " ", "circumradius"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"R", "=", 
   RowBox[{
    RowBox[{"a", "*", "b", "*", 
     RowBox[{"c", "/", 
      RowBox[{"(", 
       RowBox[{"4", "K"}], ")"}]}]}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.8230131366950617`*^9, 3.823013149494817*^9}, {
  3.823363104214463*^9, 3.823363107533408*^9}},
 CellLabel->"In[75]:=",ExpressionUUID->"17a89ecb-af0d-4a36-96be-398032170ba5"],

Cell[BoxData[
 FractionBox[
  RowBox[{"a", " ", "b", " ", "c"}], 
  SqrtBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "4"]}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], "2"], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]}]]]], "Output",
 CellChangeTimes->{3.823013150489772*^9, 3.823013401002795*^9, 
  3.823177654068201*^9, 3.8232609222151537`*^9, 3.823334488383181*^9, 
  3.823363108407557*^9, 3.823363306419341*^9, 3.8233649412067347`*^9, 
  3.823418596347661*^9, 3.823424401896756*^9},
 CellLabel->"Out[75]=",ExpressionUUID->"9fbeb268-2905-4a96-9f78-a91b65e46921"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"restrictions", " ", "on", " ", "a"}], ",", " ", "b", ",", " ", 
    RowBox[{"and", " ", "c"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"assum", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}]}]], "Input",
 CellChangeTimes->{{3.82301318882378*^9, 3.823013224639209*^9}, {
  3.823363122262713*^9, 3.823363132269806*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"07f45691-9d95-49d0-9abd-695ed9b1ccaa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", ">", "0"}], "&&", 
  RowBox[{"b", ">", "0"}], "&&", 
  RowBox[{"c", ">", "0"}], "&&", 
  RowBox[{
   RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
  RowBox[{
   RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
  RowBox[{
   RowBox[{"a", "+", "c"}], ">", "b"}]}]], "Output",
 CellChangeTimes->{3.823013225577581*^9, 3.8231776541248617`*^9, 
  3.82326092222535*^9, 3.823334488439341*^9, 3.823363134646247*^9, 
  3.823363306426005*^9, 3.823364941225788*^9, 3.823418596396508*^9, 
  3.823424401903605*^9},
 CellLabel->"Out[76]=",ExpressionUUID->"81a94ce6-9f44-4cf5-86a3-be555873dd2c"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear Inequalities", "Chapter",
 CellChangeTimes->{{3.823261285874937*^9, 
  3.823261297505422*^9}},ExpressionUUID->"bec39b7b-e162-49c1-8627-\
22a1989172fd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "1"}], ",", " ", 
    RowBox[{"inequality", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Minimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ha", "/", "r"}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823421318201746*^9, 3.8234213206257687`*^9}, {
  3.823421355050668*^9, 3.823421355996771*^9}},
 CellLabel->"In[77]:=",ExpressionUUID->"53b1b97a-67a3-46fc-86af-92ee4e4fa648"],

Cell[BoxData[
 TemplateBox[{
  "Minimize","natt",
   "\"The minimum is not attained at any point satisfying the given \
constraints.\"",2,77,9,31762920498035539176,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.823421321453232*^9, 3.823424401910252*^9},
 CellLabel->
  "During evaluation of \
In[77]:=",ExpressionUUID->"a99ca28f-66e0-4798-8777-69225de91168"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "ComplexInfinity"}], ",", 
     RowBox[{"b", "\[Rule]", "ComplexInfinity"}], ",", 
     RowBox[{"c", "\[Rule]", "Indeterminate"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823421321459433*^9, 3.823424401911044*^9},
 CellLabel->"Out[77]=",ExpressionUUID->"5a1c9fb7-55ae-401f-9930-2b7ae1914365"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "1"}], ",", " ", 
    RowBox[{"inequality", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"2", "r"}], "<", "ha"}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823421267617663*^9, 3.82342129465773*^9}},
 CellLabel->"In[78]:=",ExpressionUUID->"61beb366-83e4-4cff-8aba-a38d5489cbf8"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823421277876486*^9, 3.8234244019189243`*^9},
 CellLabel->"Out[78]=",ExpressionUUID->"2f5cbe96-de62-4186-9de9-d9e130fd3d77"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "1"}], ",", " ", 
    RowBox[{"inequality", " ", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Minimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ga", "/", "ha"}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823014291578849*^9, 3.823014351850258*^9}, {
  3.823420369801381*^9, 3.823420399848393*^9}},
 CellLabel->"In[79]:=",ExpressionUUID->"9d1ef2b1-b87c-409e-a6ef-426f070b931e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", 
      FractionBox["3", "4"]}], ",", 
     RowBox[{"c", "\[Rule]", 
      FractionBox["3", "4"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.823014294101654*^9, 3.8230143189575453`*^9}, 
   3.823014358937395*^9, 3.823177656016005*^9, 3.823260923618753*^9, 
   3.8233344897859488`*^9, 3.823363306810498*^9, 3.823364941577199*^9, 
   3.8234185968236513`*^9, 3.823420462677247*^9, 3.82342440231069*^9},
 CellLabel->"Out[79]=",ExpressionUUID->"1b0a6e53-8cbf-4bc7-bf53-0145034b9e56"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "1"}], ",", " ", 
    RowBox[{"inequality", " ", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ha", "^", "2"}], "\[LessEqual]", 
     RowBox[{"ga", "^", "2"}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823419166145688*^9, 3.823419193920413*^9}, {
  3.823419245938431*^9, 3.8234192505203867`*^9}, {3.823420407105551*^9, 
  3.8234204128962097`*^9}},
 CellLabel->"In[80]:=",ExpressionUUID->"6f420b28-1677-4ed9-abe5-0811e3492572"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823419196803876*^9, 3.823419252221261*^9, 
  3.823424402316942*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"579184ac-0746-46f5-b2d1-7e8c561a8051"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "1"}], ",", " ", 
    RowBox[{"inequality", " ", "3"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ga", "/", "wa"}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8230145519710913`*^9, 3.823014552403154*^9}, {
  3.823420604024412*^9, 3.8234206142717133`*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"f75d3054-a1f1-48e0-8096-f95d01369bee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8230145528270473`*^9, 3.823177657177946*^9, 
  3.8232609240163183`*^9, 3.823334490129195*^9, 3.8233633070730143`*^9, 
  3.823364941850193*^9, 3.823418597190166*^9, 3.823424402430777*^9},
 CellLabel->"Out[81]=",ExpressionUUID->"41dc02bb-9f62-43c5-a6f3-9cb8acfc05ee"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "1"}], ",", " ", 
    RowBox[{"inequality", " ", "3"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ga", "^", "2"}], "\[LessEqual]", 
     RowBox[{"wa", "^", "2"}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8234192677855577`*^9, 3.8234192981843576`*^9}, {
  3.8234206318485003`*^9, 3.823420636911352*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"cb34a15d-5a83-4e58-90ff-4324ddb83fcb"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.823419288443777*^9, 3.823419298703071*^9}, 
   3.823424402436989*^9},
 CellLabel->"Out[82]=",ExpressionUUID->"8c4700a6-eb09-4e07-9131-9691b3c40d99"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "1"}], ",", " ", 
    RowBox[{"inequality", " ", "4"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"wa", "/", "ma"}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823421536562455*^9, 3.823421546642459*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"fe8a6c50-3c87-467b-828f-dce445c5a092"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823421553544455*^9, 3.823424402528296*^9},
 CellLabel->"Out[83]=",ExpressionUUID->"7bdffd67-58ca-43f4-be5c-8a123f89a891"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "1"}], ",", " ", 
    RowBox[{"inequality", " ", "4"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"wa", "^", "2"}], "\[LessEqual]", 
     RowBox[{"ma", "^", "2"}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823421567338521*^9, 3.82342158966619*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"891f311b-0753-4825-bad4-1f12945bdca2"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.823421580513094*^9, 3.823421590266406*^9}, 
   3.823424402534978*^9},
 CellLabel->"Out[84]=",ExpressionUUID->"333597eb-1df3-45ac-8d62-01dec5fe0b0b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "1"}], ",", " ", 
    RowBox[{"inequality", " ", "5"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ma", "/", "na"}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8234214071541767`*^9, 3.8234214380097637`*^9}, 
   3.823421509794285*^9},
 CellLabel->"In[85]:=",ExpressionUUID->"efbc819f-daf6-47df-a23b-1e2322841282"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", 
      FractionBox["17", "32"]}], ",", 
     RowBox[{"c", "\[Rule]", 
      FractionBox["17", "32"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823421419888595*^9, 3.823424403427907*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"d6cd3b23-fd09-41a1-be8f-2f11b106e53d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "1"}], ",", " ", 
    RowBox[{"inequality", " ", "5"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ma", "^", "2"}], "<=", 
     RowBox[{"na", "^", "2"}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823419487400873*^9, 3.8234195276816387`*^9}, {
   3.823420768268997*^9, 3.823420774879993*^9}, {3.8234208193203173`*^9, 
   3.8234208273761272`*^9}, 3.8234215120178823`*^9},
 CellLabel->"In[86]:=",ExpressionUUID->"7ee3a905-251e-49af-a20b-ea2167a629d2"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.8234194926715307`*^9, 3.8234195301556683`*^9}, 
   3.82342440348964*^9},
 CellLabel->"Out[86]=",ExpressionUUID->"b5074fd8-e472-4d72-a2ea-3220eb91a010"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "1"}], ",", " ", 
    RowBox[{"inequality", " ", "6"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"na", "/", "s"}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.823182597971507*^9, {3.823420922761545*^9, 3.823420933976631*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"4db05a32-b1f0-4e71-aade-8e94ed62a8e4"],

Cell[BoxData[
 TemplateBox[{
  "Maximize","wksol",
   "\"Warning: there is no maximum in the region in which the objective \
function is defined and the constraints are satisfied; a result on the \
boundary will be returned.\"",2,87,10,31762920498035539176,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.823182921239297*^9, 3.8231831126663647`*^9, 
  3.823186719465987*^9, 3.8233344907878237`*^9, 3.823363308016581*^9, 
  3.8233649419172173`*^9, 3.82341859726956*^9, 3.823424403570644*^9},
 CellLabel->
  "During evaluation of \
In[87]:=",ExpressionUUID->"a2475f10-4d72-44b0-9e01-89355757def2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "0"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8231826000312033`*^9, 3.823182921245757*^9, 
  3.82318311267304*^9, 3.823186719473126*^9, 3.8233344907882557`*^9, 
  3.8233633080222473`*^9, 3.82336494191803*^9, 3.823418597270274*^9, 
  3.823424403571406*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"418658e2-a48b-4d94-9c8a-93ecad4fd1df"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "1"}], ",", " ", 
    RowBox[{"inequality", " ", "6"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"na", "<", "s"}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823419451449589*^9, 3.823419460184466*^9}, {
  3.823420943329465*^9, 3.823420948512373*^9}},
 CellLabel->"In[88]:=",ExpressionUUID->"c893343c-c5e3-4f58-9878-982b66545ccb"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823419461639854*^9, 3.823424403578587*^9},
 CellLabel->"Out[88]=",ExpressionUUID->"0cf4f0ca-7a11-427c-ae81-518a47283ddb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "5"}], ",", " ", 
    RowBox[{"inequality", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Minimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ga", "/", "wa"}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.823014487867277*^9, {3.823014582356985*^9, 3.823014602516445*^9}, {
   3.823363297023265*^9, 3.8233633178630743`*^9}, {3.823420493111952*^9, 
   3.823420514751195*^9}, {3.823420566271649*^9, 3.82342056905542*^9}},
 CellLabel->"In[89]:=",ExpressionUUID->"9c34e73c-6136-4e10-aef8-f611b7357e96"],

Cell[BoxData[
 TemplateBox[{
  "Minimize","wksol",
   "\"Warning: there is no minimum in the region in which the objective \
function is defined and the constraints are satisfied; returning a result on \
the boundary.\"",2,89,11,31762920498035539176,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.823363319036601*^9, 3.823364941739541*^9, 
  3.823418597016279*^9, 3.8234244037759933`*^9},
 CellLabel->
  "During evaluation of \
In[89]:=",ExpressionUUID->"c924fa9c-086d-4ce6-a690-342a8e72f141"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "2"], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "0"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.823014489438838*^9, 3.823014513612699*^9}, {
   3.823014585354745*^9, 3.823014603599345*^9}, 3.823177656282159*^9, 
   3.823260923898026*^9, 3.823334490015904*^9, {3.823363306972559*^9, 
   3.8233633190420933`*^9}, 3.823364941740303*^9, 3.823418597017949*^9, 
   3.823424403776766*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"0e76cf63-312b-4d20-b156-a22cb6464796"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "5"}], ",", " ", 
    RowBox[{"inequality", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"wa", "^", "2"}], "<", 
     RowBox[{"4", 
      RowBox[{"ga", "^", "2"}]}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.82341932235365*^9, 3.823419354264473*^9}, {
  3.8234206604087057`*^9, 3.823420683527603*^9}},
 CellLabel->"In[90]:=",ExpressionUUID->"c16e1130-e64c-4592-9aa2-3cfc9f5856fd"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.823419341037788*^9, 3.823419358066959*^9}, 
   3.823424403783627*^9},
 CellLabel->"Out[90]=",ExpressionUUID->"fbcfc4e9-8b80-4bd1-99af-8c8f0393f65a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "5"}], ",", " ", 
    RowBox[{"inequality", " ", "4"}]}], " ", "*)"}], 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"na", "/", "ma"}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823363525239143*^9, 3.823363525727189*^9}, {
  3.8234207422602863`*^9, 3.823420747120064*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"8655192f-11bb-4b07-a236-55644e5cb596"],

Cell[BoxData[
 TemplateBox[{
  "Maximize","wksol",
   "\"Warning: there is no maximum in the region in which the objective \
function is defined and the constraints are satisfied; a result on the \
boundary will be returned.\"",2,91,12,31762920498035539176,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.823363526577961*^9, 3.823364943910823*^9, 
  3.823418599550733*^9, 3.823424404168847*^9},
 CellLabel->
  "During evaluation of \
In[91]:=",ExpressionUUID->"a640c42d-0314-43c9-95eb-a2ebce99a623"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "0"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8233635265843153`*^9, 3.8233649439115677`*^9, 
  3.823418599551441*^9, 3.823424404169319*^9},
 CellLabel->"Out[91]=",ExpressionUUID->"4e8adbc7-c073-468b-985d-e3822ae597ab"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "5"}], ",", " ", 
    RowBox[{"inequality", " ", "4"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"na", "^", "2"}], "<", 
     RowBox[{"4", 
      RowBox[{"ma", "^", "2"}]}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8234195580809193`*^9, 3.823419586520339*^9}, {
  3.823420785536956*^9, 3.8234207975520697`*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"c4650fae-3da0-4122-827d-16feb5ee6627"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.823419575694067*^9, 3.823419587146563*^9}, 
   3.823424404175746*^9},
 CellLabel->"Out[92]=",ExpressionUUID->"2c6cc3f5-8d4d-41fe-9e3c-c95c6494498f"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Quadratic Inequalities involving ga", "Chapter",
 CellChangeTimes->{{3.823261357595161*^9, 3.823261371969572*^9}, {
  3.823364371561133*^9, 
  3.823364378536743*^9}},ExpressionUUID->"ffc97128-b953-41e6-90e7-\
eabc2eac17bb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Minimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"ga", "^", "2"}], "]"}], "/", 
       RowBox[{"s", "^", "2"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823021783223638*^9, 3.8230218217591248`*^9}, {
  3.8234196284980087`*^9, 3.823419632744557*^9}, {3.823419683665895*^9, 
  3.8234196840488*^9}, {3.82342285810087*^9, 3.82342286497952*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"4a6752a8-8f8f-4cb6-b1cb-c852652ee7bb"],

Cell[BoxData[
 TemplateBox[{
  "Minimize","wksol",
   "\"Warning: there is no minimum in the region in which the objective \
function is defined and the constraints are satisfied; returning a result on \
the boundary.\"",2,93,13,31762920498035539176,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.823419923014545*^9, 3.8234246464082537`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"b4bef806-f096-45f4-aed6-fd03e6fe09ab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "2"], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"c", "\[Rule]", 
      FractionBox["1", "2"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823021814778265*^9, 3.823022011980239*^9, 
  3.823365130691328*^9, 3.823418608823209*^9, 3.823419679238537*^9, 
  3.823419923021082*^9, 3.823424646409114*^9},
 CellLabel->"Out[93]=",ExpressionUUID->"65c92fed-b8fe-426c-8579-6905e5300644"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "^", "2"}], "\[LessEqual]", 
     RowBox[{"2", 
      RowBox[{"csum", "[", 
       RowBox[{"ga", "^", "2"}], "]"}]}]}], ",", "assum"}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.823021734487309*^9, 3.823021777104151*^9}, {
  3.8234228021243877`*^9, 3.823422803078524*^9}, {3.823422835612084*^9, 
  3.823422846636341*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"ad8be77f-f8dd-4f0c-935d-7406f9dea37a"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.823021743814921*^9, 3.82302177906321*^9}, 
   3.823364945649403*^9, 3.823418601798031*^9, 3.8234228378095703`*^9, 
   3.823424646482409*^9},
 CellLabel->"Out[94]=",ExpressionUUID->"2cceff19-eb0e-4240-9b8a-2adce32d8068"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"ga", "^", "2"}], "]"}], "/", 
       RowBox[{"s", "^", "2"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.82302204696799*^9, 3.823022047256051*^9}, {
  3.82342005458554*^9, 3.823420063392396*^9}, {3.82342291342069*^9, 
  3.823422924091823*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"f1581284-f66b-4e63-9140-dc5a0a6929d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823022239297041*^9, 3.823365320402157*^9, 
  3.823420306107518*^9, 3.823424881301364*^9},
 CellLabel->"Out[95]=",ExpressionUUID->"5d2c6efe-d519-4f55-a453-395c76007f42"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"csum", "[", 
      RowBox[{"ga", "^", "2"}], "]"}], "\[LessEqual]", 
     RowBox[{"s", "^", "2"}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.823189073548375*^9, 3.823418642452202*^9, {3.823422975092739*^9, 
   3.823423002011633*^9}},
 CellLabel->"In[96]:=",ExpressionUUID->"552f7dce-8143-4e26-b01e-055d0c0b78c0"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823189075853875*^9, 3.823365132000338*^9, 
  3.823418647017695*^9, 3.823423003143256*^9, 3.8234248813679132`*^9},
 CellLabel->"Out[96]=",ExpressionUUID->"02b1b581-48d4-4b2d-b8b4-fd976dabc604"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "3"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Minimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"ga", "^", "2"}], "]"}], "/", 
       RowBox[{"csum", "[", 
        RowBox[{"a", "^", "2"}], "]"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823027800256248*^9, 3.823027800744321*^9}, {
  3.823423083142468*^9, 3.8234230920842667`*^9}, {3.823423552774171*^9, 
  3.823423561149221*^9}},
 CellLabel->"In[97]:=",ExpressionUUID->"43d822c7-07a9-4faa-b5fd-699131e731b3"],

Cell[BoxData[
 TemplateBox[{
  "Minimize","wksol",
   "\"Warning: there is no minimum in the region in which the objective \
function is defined and the constraints are satisfied; returning a result on \
the boundary.\"",2,97,14,31762920498035539176,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.823028033095912*^9, 3.823366366335348*^9, 
  3.8234233717033653`*^9, 3.823425158091494*^9},
 CellLabel->
  "During evaluation of \
In[97]:=",ExpressionUUID->"5afdbf50-b77b-41c4-9e9d-89f4edd3a0bf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "3"], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"c", "\[Rule]", 
      FractionBox["1", "2"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823028033102726*^9, 3.823366366340749*^9, 
  3.8234233717085*^9, 3.8234251580923367`*^9},
 CellLabel->"Out[97]=",ExpressionUUID->"6a4f2996-5718-4189-b250-9530e5976a7b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "3"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "/", "3"}], ")"}], 
      RowBox[{"csum", "[", 
       RowBox[{"a", "^", "2"}], "]"}]}], "<", 
     RowBox[{"csum", "[", 
      RowBox[{"ga", "^", "2"}], "]"}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823021615495576*^9, 3.823021686998703*^9}, {
   3.82342275195674*^9, 3.823422784491391*^9}, {3.823423600822669*^9, 
   3.823423627509161*^9}, 3.8234238602627983`*^9},
 CellLabel->"In[98]:=",ExpressionUUID->"b9f776c8-fd2c-421a-b35f-7e9aac10e31c"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.8230216165531263`*^9, 3.823021629631135*^9}, {
   3.8230216687942*^9, 3.823021687981544*^9}, 3.823364944031934*^9, 
   3.823418599817193*^9, 3.823423636055709*^9, 3.82342515816154*^9},
 CellLabel->"Out[98]=",ExpressionUUID->"1639182e-e153-4b2d-ab13-97a9f5d217df"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "4"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"ga", "^", "2"}], "]"}], "/", 
       RowBox[{"csum", "[", 
        RowBox[{"a", "^", "2"}], "]"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.8230275144876328`*^9, {3.823423914967101*^9, 3.823423939966151*^9}},
 CellLabel->"In[99]:=",ExpressionUUID->"d6ebe9f8-ea18-4dae-95e1-3dc44f3b14bf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["3", "4"], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823027742576869*^9, 3.823366129455091*^9, 
  3.823424225984933*^9, 3.823425437509883*^9},
 CellLabel->"Out[99]=",ExpressionUUID->"9141724f-a65d-4c2d-a43e-1f8a2aa2426a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "4"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"csum", "[", 
      RowBox[{"ga", "^", "2"}], "]"}], "\[LessEqual]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "/", "4"}], ")"}], 
      RowBox[{"csum", "[", 
       RowBox[{"a", "^", "2"}], "]"}]}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{3.8234235869173403`*^9, 3.823423877438031*^9},
 CellLabel->
  "In[100]:=",ExpressionUUID->"6904b2dd-93f0-4088-8baa-c2a494ea0720"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823423894585697*^9, 3.82342543757576*^9},
 CellLabel->
  "Out[100]=",ExpressionUUID->"9cc2e70d-198c-4d4a-97bb-ec29468cbd69"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "5"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Minimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"ga", "^", "2"}], "]"}], "/", 
       RowBox[{"csum", "[", 
        RowBox[{"ma", "^", "2"}], "]"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823023168330886*^9, 3.8230231686909924`*^9}, 
   3.823023353735552*^9, {3.823423995022945*^9, 3.8234239998300877`*^9}},
 CellLabel->
  "In[101]:=",ExpressionUUID->"b447cf95-8fdc-4cb0-95db-3f4c2c121111"],

Cell[BoxData[
 TemplateBox[{
  "Minimize","wksol",
   "\"Warning: there is no minimum in the region in which the objective \
function is defined and the constraints are satisfied; returning a result on \
the boundary.\"",2,101,15,31762920498035539176,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.823023169717844*^9, 3.823023998671178*^9, 
  3.8233658051993847`*^9, 3.823425747259396*^9},
 CellLabel->
  "During evaluation of \
In[101]:=",ExpressionUUID->"25982bcb-2249-42c9-a191-375163b5b05e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["4", "9"], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"c", "\[Rule]", 
      FractionBox["1", "2"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823023169724527*^9, 3.823023998678153*^9, 
  3.823365805200468*^9, 3.82342574726033*^9},
 CellLabel->
  "Out[101]=",ExpressionUUID->"17cf824e-672d-4234-a176-b5ee66ae9602"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "5"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4", "/", "9"}], ")"}], 
      RowBox[{"csum", "[", 
       RowBox[{"ma", "^", "2"}], "]"}]}], "<", 
     RowBox[{"csum", "[", 
      RowBox[{"ga", "^", "2"}], "]"}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823424255678747*^9, 3.823424297454908*^9}},
 CellLabel->
  "In[102]:=",ExpressionUUID->"9afee9ab-9674-4c2c-bf17-9473e721fd1f"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823424301194798*^9, 3.823425747331431*^9},
 CellLabel->
  "Out[102]=",ExpressionUUID->"01e1c4eb-d88d-40fd-9993-31910b9b3a78"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "6"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"ga", "^", "2"}], "]"}], "/", 
       RowBox[{"csum", "[", 
        RowBox[{"ma", "^", "2"}], "]"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.823023158778914*^9, 3.823023349007864*^9, {3.823423974766904*^9, 
   3.823423985814228*^9}},
 CellLabel->
  "In[103]:=",ExpressionUUID->"02a59526-2316-4f3f-9110-f2826745556c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823023160071822*^9, 3.823023599451337*^9, 
  3.823365562589335*^9, 3.8234260598135357`*^9},
 CellLabel->
  "Out[103]=",ExpressionUUID->"b8ab6446-30ca-4227-aefd-b281e596c314"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "6"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"csum", "[", 
      RowBox[{"ga", "^", "2"}], "]"}], "\[LessEqual]", 
     RowBox[{"csum", "[", 
      RowBox[{"ma", "^", "2"}], "]"}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823424318694853*^9, 3.823424342302589*^9}},
 CellLabel->
  "In[104]:=",ExpressionUUID->"52dc2371-8352-42e8-9db9-16a15e8199e7"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823424343935193*^9, 3.8234260598814297`*^9},
 CellLabel->
  "Out[104]=",ExpressionUUID->"3ca74e9e-d6e7-444f-9f8d-47ce205ea9be"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "7"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"csum", "[", 
      RowBox[{"ga", "^", "2"}], "]"}], "\[GreaterEqual]", 
     RowBox[{"27", 
      RowBox[{"r", "^", "2"}]}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823198121505596*^9, 3.823198125689229*^9}, {
  3.823424064287003*^9, 3.823424069198286*^9}},
 CellLabel->
  "In[105]:=",ExpressionUUID->"a2b5d2cf-0802-45d5-a5e8-1b99607fd014"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8231981296252747`*^9, 3.823366585247583*^9, 
  3.823426063322669*^9},
 CellLabel->
  "Out[105]=",ExpressionUUID->"ca180a8c-27d4-4253-baab-519f33e81515"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "8"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"csum", "[", 
      RowBox[{"ga", "^", "2"}], "]"}], "\[LessEqual]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"27", "/", "4"}], ")"}], 
      RowBox[{"R", "^", "2"}]}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8231976852166147`*^9, 3.823197687512323*^9}, {
  3.823424045438972*^9, 3.823424057382229*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"201e04e7-456a-4cd4-b1cb-7bf0ac553516"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823197774170538*^9, 3.823366582467783*^9, 
  3.823426152733531*^9},
 CellLabel->
  "Out[106]=",ExpressionUUID->"305ece02-43c0-483e-a873-aa1070e6a243"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "6"}], ",", " ", 
    RowBox[{"inequality", " ", "9"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"csum", "[", 
      RowBox[{"ga", "^", "2"}], "]"}], "\[GreaterEqual]", 
     RowBox[{"3", 
      RowBox[{"Sqrt", "[", "3", "]"}], "K"}]}], ",", "assum"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.823361946153975*^9, 3.8233619747376833`*^9}, {
  3.82342402833501*^9, 3.823424040246423*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"1f3883f0-2f27-47f4-9ef4-d1ecfc5b65c5"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823362106751878*^9, 3.8233665107622128`*^9, 
  3.82342632417585*^9},
 CellLabel->
  "Out[107]=",ExpressionUUID->"76bf0306-0766-4bf1-8430-cb4e3d1ec376"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Quadratic Inequalities involving na", "Chapter",
 CellChangeTimes->{{3.823261357595161*^9, 3.823261371969572*^9}, {
   3.823364371561133*^9, 3.823364378536743*^9}, 
   3.823364554761756*^9},ExpressionUUID->"648091e2-c01f-4ed8-897d-\
a7ed0eb6cf75"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "1"}]}], " ", "*)"}], 
  RowBox[{"Minimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"na", "^", "2"}], "]"}], "/", 
       RowBox[{"s", "^", "2"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8232658897046137`*^9, 3.82326589088829*^9}, {
  3.8234279249828043`*^9, 3.823427929994811*^9}, {3.823427960634582*^9, 
  3.823427983122573*^9}},ExpressionUUID->"f422c591-c203-4f7b-b1a9-\
725504f5f1ad"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823265892228376*^9, 3.82336744304537*^9, 
  3.823426956352776*^9},
 CellLabel->
  "Out[111]=",ExpressionUUID->"ed62a678-178c-4fe1-9d3b-46e19570c991"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "^", "2"}], "\[LessEqual]", 
     RowBox[{"csum", "[", 
      RowBox[{"na", "^", "2"}], "]"}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823429604992915*^9, 3.823429625385833*^9}},
 CellLabel->
  "In[121]:=",ExpressionUUID->"a33e90e2-f897-41c3-8c7e-934f0935a3e1"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8234296313267193`*^9},
 CellLabel->
  "Out[121]=",ExpressionUUID->"02c7a4b9-fd65-451d-9828-1f5dca1ab29f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"na", "^", "2"}], "]"}], "/", 
       RowBox[{"s", "^", "2"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823265905704484*^9, 3.823265906272419*^9}, {
  3.8232661056428022`*^9, 3.8232661090488777`*^9}, {3.823427993544541*^9, 
  3.823427997618986*^9}},ExpressionUUID->"687e9145-a006-4f8f-b2d4-\
95753f7d8a49"],

Cell[BoxData[
 TemplateBox[{
  "Maximize","natt",
   "\"The maximum is not attained at any point satisfying the given \
constraints. \"",2,112,17,31762920498035539176,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8232659070559464`*^9, 3.82336744326759*^9, 
  3.8234269565876427`*^9},
 CellLabel->
  "During evaluation of \
In[112]:=",ExpressionUUID->"bcb08ecf-f4d2-4d10-9d84-3d2b42a45df7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "Indeterminate"}], ",", 
     RowBox[{"c", "\[Rule]", "Indeterminate"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8232659070624743`*^9, 3.8233674432730827`*^9, 
  3.823426956593337*^9},
 CellLabel->
  "Out[112]=",ExpressionUUID->"ff050ec6-41a2-4a4b-b1ea-c32a66a383ef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"csum", "[", 
      RowBox[{"na", "^", "2"}], "]"}], "<", 
     RowBox[{"3", 
      RowBox[{"s", "^", "2"}]}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823429644936895*^9, 3.8234296767379827`*^9}},
 CellLabel->
  "In[124]:=",ExpressionUUID->"20626b2b-d0fb-4c7b-885f-7550de1d9fb0"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.823429658975951*^9, 3.823429677459981*^9}},
 CellLabel->
  "Out[124]=",ExpressionUUID->"550f9aaf-806d-4490-b704-8d7eeb90d50b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "3"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Minimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"na", "^", "2"}], "]"}], "/", 
       RowBox[{"csum", "[", 
        RowBox[{"a", "^", "2"}], "]"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8232661521144533`*^9, 3.823266161467857*^9}, {
   3.823428006295945*^9, 3.823428007334195*^9}, {3.823428056571162*^9, 
   3.823428058634902*^9}, 3.823428134595092*^9, 
   3.8234294820082617`*^9},ExpressionUUID->"abf8c38c-3265-4fa2-bbed-\
c2f66882983a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["3", "4"], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823266156326195*^9, 3.823266240806621*^9, 
  3.823266743924819*^9, 3.823367674331628*^9, 3.823427244317316*^9},
 CellLabel->
  "Out[113]=",ExpressionUUID->"2673f262-a75d-470c-ae9f-12d87884018f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "3"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "/", "4"}], ")"}], 
      RowBox[{"csum", "[", 
       RowBox[{"a", "^", "2"}], "]"}]}], "\[LessEqual]", 
     RowBox[{"csum", "[", 
      RowBox[{"na", "^", "2"}], "]"}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.82341884638551*^9, 3.823418909208427*^9}, {
   3.823428158284236*^9, 3.823428163067184*^9}, 3.82342819508317*^9, 
   3.823429462688237*^9},ExpressionUUID->"3199586c-b5a1-45f9-adc1-\
e593ae96359a"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8234189145823917`*^9, 3.823427540094388*^9},
 CellLabel->
  "Out[115]=",ExpressionUUID->"e41cd5d2-5dc0-4f56-aede-85b9e4126520"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "4"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"na", "^", "2"}], "]"}], "/", 
       RowBox[{"csum", "[", 
        RowBox[{"a", "^", "2"}], "]"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823266248899089*^9, 3.82326624941112*^9}, {
   3.823428073123973*^9, 3.823428111707007*^9}, 
   3.823429488784191*^9},ExpressionUUID->"a71e4b85-e602-4b02-b83a-\
98d7e839e30e"],

Cell[BoxData[
 TemplateBox[{
  "Maximize","natt",
   "\"The maximum is not attained at any point satisfying the given \
constraints. \"",2,114,18,31762920498035539176,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.82326649051766*^9, 3.8233679173073997`*^9, 
  3.823427539940402*^9},
 CellLabel->
  "During evaluation of \
In[114]:=",ExpressionUUID->"cd79e6c1-b98d-4900-b8e1-5620beac3b50"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["3", "2"], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "Indeterminate"}], ",", 
     RowBox[{"c", "\[Rule]", "Indeterminate"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.82326649052528*^9, 3.823367917312769*^9, 
  3.823427539946786*^9},
 CellLabel->
  "Out[114]=",ExpressionUUID->"ce069587-2d4f-4f2e-877a-d79ef4648820"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "4"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"csum", "[", 
      RowBox[{"na", "^", "2"}], "]"}], "<", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "/", "2"}], ")"}], 
      RowBox[{"csum", "[", 
       RowBox[{"a", "^", "2"}], "]"}]}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823418939840839*^9, 3.823418978256847*^9}, {
   3.82342820164439*^9, 3.823428212691558*^9}, 
   3.8234294588722887`*^9},ExpressionUUID->"8e019a3e-3eb8-43ed-aa1c-\
a0df059af281"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823418980183609*^9, 3.823427540102516*^9},
 CellLabel->
  "Out[116]=",ExpressionUUID->"b2d01d86-630a-45ed-bcb9-f322f70a4406"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "5"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Minimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"na", "^", "2"}], "]"}], "/", 
       RowBox[{"csum", "[", 
        RowBox[{"ma", "^", "2"}], "]"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823264003785027*^9, 3.823264007720892*^9}, {
  3.823427856275426*^9, 
  3.823427893506508*^9}},ExpressionUUID->"64a33d2a-4a64-4d2a-ac00-\
6faecc97d8e7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823264269943276*^9, 3.823367184882523*^9, 
  3.82342663526792*^9},
 CellLabel->
  "Out[109]=",ExpressionUUID->"02d6c65c-01e8-42b6-9f48-d1bc80c34464"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "5"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"csum", "[", 
      RowBox[{"ma", "^", "2"}], "]"}], "\[LessEqual]", 
     RowBox[{"csum", "[", 
      RowBox[{"na", "^", "2"}], "]"}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823429704985133*^9, 3.823429719936981*^9}},
 CellLabel->
  "In[125]:=",ExpressionUUID->"1b9fdf22-c887-473b-864d-9980ada5102f"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823429724584673*^9},
 CellLabel->
  "Out[125]=",ExpressionUUID->"2d63de29-3a6f-409f-a36d-669a26510400"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "6"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"na", "^", "2"}], "]"}], "/", 
       RowBox[{"csum", "[", 
        RowBox[{"ma", "^", "2"}], "]"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8232643065631313`*^9, 3.823264307067284*^9}, {
  3.823427901827532*^9, 
  3.823427908722712*^9}},ExpressionUUID->"d373848f-5d51-4f05-8911-\
61ef6a03607d"],

Cell[BoxData[
 TemplateBox[{
  "Maximize","natt",
   "\"The maximum is not attained at any point satisfying the given \
constraints. \"",2,110,16,31762920498035539176,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8232645607017508`*^9, 3.823367442871318*^9, 
  3.823426956193389*^9},
 CellLabel->
  "During evaluation of \
In[110]:=",ExpressionUUID->"608619d6-1284-4768-95c4-cb8747a05924"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "Indeterminate"}], ",", 
     RowBox[{"c", "\[Rule]", "Indeterminate"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8232645607126417`*^9, 3.823367442879397*^9, 
  3.8234269562001953`*^9},
 CellLabel->
  "Out[110]=",ExpressionUUID->"35bd4055-587d-4aed-8a95-76f1db7b4a93"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "6"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"csum", "[", 
      RowBox[{"na", "^", "2"}], "]"}], "<", 
     RowBox[{"2", 
      RowBox[{"csum", "[", 
       RowBox[{"2", 
        RowBox[{"ma", "^", "2"}]}], "]"}]}]}], ",", "assum"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.823429738673153*^9, 3.823429766059203*^9}},
 CellLabel->
  "In[126]:=",ExpressionUUID->"9ce22adb-5f16-478b-a29f-b2ec3da33e79"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823429772552218*^9},
 CellLabel->
  "Out[126]=",ExpressionUUID->"37f96d83-993a-4380-9489-2a74ecf81188"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "7"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Minimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"na", "^", "2"}], "]"}], "/", 
       RowBox[{"r", "^", "2"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8232669327019587`*^9, 3.8232669337333937`*^9}, {
  3.8234295465120277`*^9, 
  3.8234295531365643`*^9}},ExpressionUUID->"25866e31-86d8-4fd1-bd9b-\
b5205d61d02d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"27", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.82326865759968*^9, 3.8233692472516127`*^9, 
  3.8234291844495707`*^9},
 CellLabel->
  "Out[117]=",ExpressionUUID->"9b13e5af-a141-49a5-8313-3c201ed13d21"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "7"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"27", 
      RowBox[{"r", "^", "2"}]}], "<=", 
     RowBox[{"csum", "[", 
      RowBox[{"na", "^", "2"}], "]"}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823429790217373*^9, 3.823429810985032*^9}},
 CellLabel->
  "In[127]:=",ExpressionUUID->"f4e4a7a2-e363-4479-a222-a91d31df2350"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823429837852147*^9},
 CellLabel->
  "Out[127]=",ExpressionUUID->"150820d1-7ee2-41ce-8d36-526278ba025a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "8"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"csum", "[", 
      RowBox[{"na", "^", "2"}], "]"}], "<=", 
     RowBox[{"12", 
      RowBox[{"R", "^", "2"}]}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823361438962451*^9, 3.823361451498108*^9}, {
  3.8234282329964447`*^9, 
  3.8234282462843037`*^9}},ExpressionUUID->"598acdce-90f8-43c4-b0e9-\
fe26fa5543a4"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8233614524856577`*^9, 3.8233692848765373`*^9, 
  3.823429231387059*^9},
 CellLabel->
  "Out[118]=",ExpressionUUID->"7d4b42bf-0b8e-4820-938e-ffa811432879"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "7"}], ",", " ", 
    RowBox[{"inequality", " ", "9"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"csum", "[", 
      RowBox[{"na", "^", "2"}], "]"}], "\[GreaterEqual]", 
     RowBox[{"3", 
      RowBox[{"Sqrt", "[", "3", "]"}], "K"}]}], ",", "assum"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{
  3.823362220355246*^9, {3.8234282540284767`*^9, 
   3.823428264915709*^9}},ExpressionUUID->"8642227c-2e0a-4462-9861-\
a3772606ec16"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8233622825608253`*^9, 3.823369352863624*^9, 
  3.823429313491835*^9},
 CellLabel->
  "Out[119]=",ExpressionUUID->"f888a01c-d811-47ba-b05e-2cbb09b84d04"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Quadratic Inequalities involving ga and na", "Chapter",
 CellChangeTimes->{{3.823261357595161*^9, 3.823261371969572*^9}, {
   3.823364371561133*^9, 3.823364378536743*^9}, 3.823364554761756*^9, {
   3.8233647108261833`*^9, 
   3.823364712692008*^9}},ExpressionUUID->"67668c2d-b754-46c1-8f1b-\
0589448f620e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "4"}], ",", " ", 
    RowBox[{"inequality", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Minimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"ga", "^", "2"}], "]"}], "/", 
       RowBox[{"csum", "[", 
        RowBox[{"na", "^", "2"}], "]"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.823263235438817*^9, {3.823422015924654*^9, 3.823422035315557*^9}},
 CellLabel->
  "In[128]:=",ExpressionUUID->"2f676007-bb6a-4b20-b5c3-201a43d567e9"],

Cell[BoxData[
 TemplateBox[{
  "Minimize","wksol",
   "\"Warning: there is no minimum in the region in which the objective \
function is defined and the constraints are satisfied; returning a result on \
the boundary.\"",2,128,19,31762920498035539176,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.823430174784391*^9},
 CellLabel->
  "During evaluation of \
In[128]:=",ExpressionUUID->"0b8d649b-e483-4ebf-9657-57815681b605"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "4"], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"c", "\[Rule]", 
      FractionBox["1", "2"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823263484792252*^9, 3.823369602245076*^9, 
  3.8234295805994167`*^9, 3.8234301747920103`*^9},
 CellLabel->
  "Out[128]=",ExpressionUUID->"44331ef2-5bb0-4005-a4cf-cec3ee4a4be9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "4"}], ",", " ", 
    RowBox[{"inequality", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"csum", "[", 
      RowBox[{"na", "^", "2"}], "]"}], "<", 
     RowBox[{"4", 
      RowBox[{"csum", "[", 
       RowBox[{"ga", "^", "2"}], "]"}]}]}], ",", "assum"}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.823422102324502*^9, 3.823422160235952*^9}},
 CellLabel->
  "In[129]:=",ExpressionUUID->"7e5227c4-d342-4498-bb7e-09b8acc723c6"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823422146456333*^9, 3.8234304449795427`*^9},
 CellLabel->
  "Out[129]=",ExpressionUUID->"2531ade1-87ad-4d02-927b-ec7b519d9f63"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "4"}], ",", " ", 
    RowBox[{"inequality", " ", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"csum", "[", 
        RowBox[{"ga", "^", "2"}], "]"}], "/", 
       RowBox[{"csum", "[", 
        RowBox[{"na", "^", "2"}], "]"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823263505799368*^9, 3.8232635063594418`*^9}, {
  3.8234220855873613`*^9, 3.8234220920839777`*^9}},
 CellLabel->
  "In[130]:=",ExpressionUUID->"9131da45-451a-4517-9634-94ff3811ff4c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823263756691889*^9, 3.82336984379808*^9, 
  3.8234307513438168`*^9},
 CellLabel->
  "Out[130]=",ExpressionUUID->"0c31dbf0-e9bc-4a2a-a4d3-0773a92738ab"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "4"}], ",", " ", 
    RowBox[{"inequality", " ", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"csum", "[", 
      RowBox[{"ga", "^", "2"}], "]"}], "<=", 
     RowBox[{"csum", "[", 
      RowBox[{"na", "^", "2"}], "]"}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823422171380237*^9, 3.823422195675931*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"23ec01ce-4d85-41eb-82b1-019a454b889a"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823422197824738*^9, 3.823430751409062*^9},
 CellLabel->
  "Out[131]=",ExpressionUUID->"6669cdc3-141e-4155-9965-b15633c8bd2a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "8"}], ",", " ", 
    RowBox[{"inequality", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"csum", "[", 
          RowBox[{"na", "^", "2"}], "]"}], "-", 
         RowBox[{"csum", "[", 
          RowBox[{"ga", "^", "2"}], "]"}]}], ")"}], "/", 
       RowBox[{"s", "^", "2"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8233518220666533`*^9, 3.8233518368791933`*^9}, {
   3.8234220513550243`*^9, 3.823422052854741*^9}, 3.823422214620511*^9},
 CellLabel->
  "In[132]:=",ExpressionUUID->"21dba3d8-1427-49d4-b896-89ed8d5143de"],

Cell[BoxData[
 TemplateBox[{
  "Maximize","natt",
   "\"The maximum is not attained at any point satisfying the given \
constraints. \"",2,132,20,31762920498035539176,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.823351987540101*^9, 3.823369994317048*^9, 
  3.823430932060223*^9},
 CellLabel->
  "During evaluation of \
In[132]:=",ExpressionUUID->"e228f145-cdac-4fe8-a985-22605ffc3f21"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "Indeterminate"}], ",", 
     RowBox[{"c", "\[Rule]", "Indeterminate"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.82335198754708*^9, 3.823369994322687*^9, 
  3.823430932066086*^9},
 CellLabel->
  "Out[132]=",ExpressionUUID->"174ad347-4471-42e5-aa26-15dfc92568a1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "8"}], ",", " ", 
    RowBox[{"inequality", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"csum", "[", 
       RowBox[{"na", "^", "2"}], "]"}], "-", 
      RowBox[{"csum", "[", 
       RowBox[{"ga", "^", "2"}], "]"}]}], "<", 
     RowBox[{"2", 
      RowBox[{"s", "^", "2"}]}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8234223256927233`*^9, 3.823422343452477*^9}},
 CellLabel->
  "In[133]:=",ExpressionUUID->"edf90c57-f00b-4148-9918-00062415b111"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823422344946786*^9, 3.823430932161022*^9},
 CellLabel->
  "Out[133]=",ExpressionUUID->"af197b48-bf21-4fde-9e05-9e3aad7d1f78"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"no", " ", "lower", " ", "bound"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Minimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"csum", "[", 
          RowBox[{"na", "^", "2"}], "]"}], "-", 
         RowBox[{"csum", "[", 
          RowBox[{"ga", "^", "2"}], "]"}]}], ")"}], "/", 
       RowBox[{"s", "^", "2"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823352019831409*^9, 3.82335202018347*^9}, {
  3.8234225355562897`*^9, 3.8234225448430033`*^9}},
 CellLabel->
  "In[134]:=",ExpressionUUID->"47a23dc1-d78b-407e-b07f-5e462e217e11"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823352169837249*^9, 3.8233701436629553`*^9, 
  3.823431114289196*^9},
 CellLabel->
  "Out[134]=",ExpressionUUID->"fbe15355-9a5d-4f20-bcf9-ef737e376e55"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "8"}], ",", " ", 
    RowBox[{"inequality", " ", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Minimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"csum", "[", 
          RowBox[{"na", "^", "2"}], "]"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", "4"}], ")"}], 
          RowBox[{"csum", "[", 
           RowBox[{"ga", "^", "2"}], "]"}]}]}], ")"}], "/", 
       RowBox[{"s", "^", "2"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8233531220750017`*^9, 3.823353124279455*^9}, {
  3.823422254925668*^9, 3.823422261668585*^9}},
 CellLabel->
  "In[135]:=",ExpressionUUID->"da3801e0-9a53-4665-a325-a4e645a6a14e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["3", "4"], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "1"}], ",", 
     RowBox[{"c", "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823353427458124*^9, 3.823370462122114*^9, 
  3.823431488914833*^9},
 CellLabel->
  "Out[135]=",ExpressionUUID->"6a96d870-9247-472a-ac2b-e35d65875cea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "8"}], ",", " ", 
    RowBox[{"inequality", " ", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "/", "4"}], ")"}], 
      RowBox[{"s", "^", "2"}]}], "<=", 
     RowBox[{
      RowBox[{"csum", "[", 
       RowBox[{"na", "^", "2"}], "]"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "/", "4"}], ")"}], 
       RowBox[{"csum", "[", 
        RowBox[{"ga", "^", "2"}], "]"}]}]}]}], ",", "assum"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.823422358292715*^9, 3.8234223857793713`*^9}, {
  3.823422421274865*^9, 3.823422428066584*^9}},
 CellLabel->
  "In[136]:=",ExpressionUUID->"d4479e9e-01d2-4384-a281-aa2057310bb3"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823422430025139*^9, 3.823431488978517*^9},
 CellLabel->
  "Out[136]=",ExpressionUUID->"3a0e3c63-e4e4-4542-83bc-c17143086e71"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Discovery", " ", "of", " ", "Theorem", " ", "8"}], ",", " ", 
    RowBox[{"inequality", " ", "3"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"csum", "[", 
          RowBox[{"na", "^", "2"}], "]"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", "4"}], ")"}], 
          RowBox[{"csum", "[", 
           RowBox[{"ga", "^", "2"}], "]"}]}]}], ")"}], "/", 
       RowBox[{"s", "^", "2"}]}], ",", "assum"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.823353605596377*^9, 3.8233536061564627`*^9}, {
  3.823422269773437*^9, 3.8234222754607353`*^9}},
 CellLabel->
  "In[137]:=",ExpressionUUID->"19a437d5-16f7-4221-a83f-98b42a334c96"],

Cell[BoxData[
 TemplateBox[{
  "Maximize","natt",
   "\"The maximum is not attained at any point satisfying the given \
constraints. \"",2,137,21,31762920498035539176,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.823353910559177*^9, 3.823370782477944*^9, 
  3.823431871999427*^9},
 CellLabel->
  "During evaluation of \
In[137]:=",ExpressionUUID->"3da898c0-43e3-4f19-b4ae-526ec8b0e5bb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["11", "4"], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "Indeterminate"}], ",", 
     RowBox[{"c", "\[Rule]", "Indeterminate"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.823353910566553*^9, 3.82337078248593*^9, 
  3.823431872005701*^9},
 CellLabel->
  "Out[137]=",ExpressionUUID->"271bc887-43a2-44b7-8e4c-12fd8c9f1d7b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Proof", " ", "of", " ", "Theorem", " ", "8"}], ",", " ", 
    RowBox[{"inequality", " ", "3"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"csum", "[", 
       RowBox[{"na", "^", "2"}], "]"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "/", "4"}], ")"}], 
       RowBox[{"csum", "[", 
        RowBox[{"ga", "^", "2"}], "]"}]}]}], "<", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"11", "/", "4"}], ")"}], 
      RowBox[{"s", "^", "2"}]}]}], ",", "assum"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.82342245566704*^9, 3.823422484674645*^9}},
 CellLabel->
  "In[138]:=",ExpressionUUID->"bcb9d77e-1bdb-4f99-8588-f749ca1e27c5"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.823422486530532*^9, 3.823431872133725*^9},
 CellLabel->
  "Out[138]=",ExpressionUUID->"949230d9-e262-4d7f-a071-bbd949f8f957"]
}, Open  ]]
}, Closed]]
},
WindowSize->{808, 911},
WindowMargins->{{830, Automatic}, {Automatic, 71}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 897, 16, 219, "Text",ExpressionUUID->"64fd82a1-8e0f-43f3-86ab-455e67903074",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1480, 40, 159, 3, 69, "Chapter",ExpressionUUID->"0a4874d9-3130-4a27-a30f-2e8f0459f162"],
Cell[1642, 45, 1245, 33, 73, "Input",ExpressionUUID->"dd3203e7-630d-4de8-a023-9b29d99ff1a6"],
Cell[2890, 80, 395, 10, 52, "Input",ExpressionUUID->"1fa983dd-8923-4f11-b5c0-a4881ad377ce"],
Cell[CellGroupData[{
Cell[3310, 94, 696, 20, 52, "Input",ExpressionUUID->"35752e91-8d8c-4ddf-8db4-4082c0e63eb2"],
Cell[4009, 116, 878, 26, 71, "Output",ExpressionUUID->"d357b4bf-7cfc-4eca-9bef-9c1e6cc23d8f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4924, 147, 997, 27, 94, "Input",ExpressionUUID->"f5bbd733-be0d-4394-900c-0272bd8fce2e"],
Cell[5924, 176, 951, 26, 72, "Output",ExpressionUUID->"844f63f2-88db-4304-8f73-e235a20e268c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6912, 207, 638, 18, 52, "Input",ExpressionUUID->"7deb680b-02ca-4abb-9b41-20c7ceb43934"],
Cell[7553, 227, 577, 15, 50, "Output",ExpressionUUID->"4ea86878-009a-4357-8e3f-65daff0ecad4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8167, 247, 611, 16, 52, "Input",ExpressionUUID->"aa36aeb7-fc56-4cd4-a6c0-44146bf44443"],
Cell[8781, 265, 756, 20, 77, "Output",ExpressionUUID->"77db841f-e9cd-4324-87ea-9a5fdf4bc1fb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9574, 290, 589, 16, 52, "Input",ExpressionUUID->"56f18171-bcbe-483d-a943-cc542dd682e7"],
Cell[10166, 308, 833, 22, 58, "Output",ExpressionUUID->"aadbe506-da57-4e68-ba5e-617ae7e9309d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11036, 335, 448, 11, 52, "Input",ExpressionUUID->"f972d136-f2d8-4809-a49a-befbb2b2f27a"],
Cell[11487, 348, 812, 22, 77, "Output",ExpressionUUID->"2f93e7d4-b72d-4e47-9ede-55087ee743f5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12336, 375, 428, 10, 52, "Input",ExpressionUUID->"edf11d8e-1c85-4cfe-a5b5-4f1597686d98"],
Cell[12767, 387, 861, 24, 78, "Output",ExpressionUUID->"ebc697fb-037c-4b2f-a81a-bbc3463a4141"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13665, 416, 518, 13, 52, "Input",ExpressionUUID->"17a89ecb-af0d-4a36-96be-398032170ba5"],
Cell[14186, 431, 816, 22, 78, "Output",ExpressionUUID->"9fbeb268-2905-4a96-9f78-a91b65e46921"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15039, 458, 737, 19, 52, "Input",ExpressionUUID->"07f45691-9d95-49d0-9abd-695ed9b1ccaa"],
Cell[15779, 479, 612, 15, 34, "Output",ExpressionUUID->"81a94ce6-9f44-4cf5-86a3-be555873dd2c"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[16440, 500, 164, 3, 58, "Chapter",ExpressionUUID->"bec39b7b-e162-49c1-8627-22a1989172fd"],
Cell[CellGroupData[{
Cell[16629, 507, 620, 15, 52, "Input",ExpressionUUID->"53b1b97a-67a3-46fc-86af-92ee4e4fa648"],
Cell[17252, 524, 383, 9, 24, "Message",ExpressionUUID->"a99ca28f-66e0-4798-8777-69225de91168"],
Cell[17638, 535, 411, 9, 34, "Output",ExpressionUUID->"5a1c9fb7-55ae-401f-9930-2b7ae1914365"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18086, 549, 475, 11, 52, "Input",ExpressionUUID->"61beb366-83e4-4cff-8aba-a38d5489cbf8"],
Cell[18564, 562, 176, 2, 34, "Output",ExpressionUUID->"2f5cbe96-de62-4186-9de9-d9e130fd3d77"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18777, 569, 623, 15, 52, "Input",ExpressionUUID->"9d1ef2b1-b87c-409e-a6ef-426f070b931e"],
Cell[19403, 586, 638, 14, 50, "Output",ExpressionUUID->"1b0a6e53-8cbf-4bc7-bf53-0145034b9e56"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20078, 605, 621, 14, 52, "Input",ExpressionUUID->"6f420b28-1677-4ed9-abe5-0811e3492572"],
Cell[20702, 621, 199, 3, 34, "Output",ExpressionUUID->"579184ac-0746-46f5-b2d1-7e8c561a8051"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20938, 629, 627, 15, 52, "Input",ExpressionUUID->"f75d3054-a1f1-48e0-8096-f95d01369bee"],
Cell[21568, 646, 515, 11, 34, "Output",ExpressionUUID->"41dc02bb-9f62-43c5-a6f3-9cb8acfc05ee"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22120, 662, 574, 13, 52, "Input",ExpressionUUID->"cb34a15d-5a83-4e58-90ff-4324ddb83fcb"],
Cell[22697, 677, 202, 3, 34, "Output",ExpressionUUID->"8c4700a6-eb09-4e07-9131-9691b3c40d99"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22936, 685, 574, 14, 52, "Input",ExpressionUUID->"fe8a6c50-3c87-467b-828f-dce445c5a092"],
Cell[23513, 701, 371, 9, 34, "Output",ExpressionUUID->"7bdffd67-58ca-43f4-be5c-8a123f89a891"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23921, 715, 518, 12, 52, "Input",ExpressionUUID->"891f311b-0753-4825-bad4-1f12945bdca2"],
Cell[24442, 729, 202, 3, 34, "Output",ExpressionUUID->"333597eb-1df3-45ac-8d62-01dec5fe0b0b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24681, 737, 604, 15, 52, "Input",ExpressionUUID->"efbc819f-daf6-47df-a23b-1e2322841282"],
Cell[25288, 754, 425, 11, 51, "Output",ExpressionUUID->"d6cd3b23-fd09-41a1-be8f-2f11b106e53d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25750, 770, 639, 14, 52, "Input",ExpressionUUID->"7ee3a905-251e-49af-a20b-ea2167a629d2"],
Cell[26392, 786, 205, 3, 34, "Output",ExpressionUUID->"b5074fd8-e472-4d72-a2ea-3220eb91a010"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26634, 794, 598, 15, 52, "Input",ExpressionUUID->"4db05a32-b1f0-4e71-aade-8e94ed62a8e4"],
Cell[27235, 811, 619, 12, 42, "Message",ExpressionUUID->"a2475f10-4d72-44b0-9e01-89355757def2"],
Cell[27857, 825, 538, 12, 34, "Output",ExpressionUUID->"418658e2-a48b-4d94-9c8a-93ecad4fd1df"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28432, 842, 504, 11, 52, "Input",ExpressionUUID->"c893343c-c5e3-4f58-9878-982b66545ccb"],
Cell[28939, 855, 174, 2, 34, "Output",ExpressionUUID->"0cf4f0ca-7a11-427c-ae81-518a47283ddb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29150, 862, 746, 17, 52, "Input",ExpressionUUID->"9c34e73c-6136-4e10-aef8-f611b7357e96"],
Cell[29899, 881, 518, 11, 42, "Message",ExpressionUUID->"c924fa9c-086d-4ce6-a690-342a8e72f141"],
Cell[30420, 894, 637, 14, 50, "Output",ExpressionUUID->"0e76cf63-312b-4d20-b156-a22cb6464796"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31094, 913, 580, 14, 52, "Input",ExpressionUUID->"c16e1130-e64c-4592-9aa2-3cfc9f5856fd"],
Cell[31677, 929, 202, 3, 34, "Output",ExpressionUUID->"fbcfc4e9-8b80-4bd1-99af-8c8f0393f65a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31916, 937, 602, 15, 52, "Input",ExpressionUUID->"8655192f-11bb-4b07-a236-55644e5cb596"],
Cell[32521, 954, 523, 11, 42, "Message",ExpressionUUID->"a640c42d-0314-43c9-95eb-a2ebce99a623"],
Cell[33047, 967, 422, 10, 34, "Output",ExpressionUUID->"4e8adbc7-c073-468b-985d-e3822ae597ab"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33506, 982, 583, 14, 52, "Input",ExpressionUUID->"c4650fae-3da0-4122-827d-16feb5ee6627"],
Cell[34092, 998, 202, 3, 34, "Output",ExpressionUUID->"2c6cc3f5-8d4d-41fe-9e3c-c95c6494498f"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[34343, 1007, 229, 4, 58, "Chapter",ExpressionUUID->"ffc97128-b953-41e6-90e7-eabc2eac17bb"],
Cell[CellGroupData[{
Cell[34597, 1015, 810, 19, 52, "Input",ExpressionUUID->"4a6752a8-8f8f-4cb6-b1cb-c852652ee7bb"],
Cell[35410, 1036, 471, 10, 42, "Message",ExpressionUUID->"b4bef806-f096-45f4-aed6-fd03e6fe09ab"],
Cell[35884, 1048, 559, 14, 50, "Output",ExpressionUUID->"65c92fed-b8fe-426c-8579-6905e5300644"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36480, 1067, 678, 17, 52, "Input",ExpressionUUID->"ad8be77f-f8dd-4f0c-935d-7406f9dea37a"],
Cell[37161, 1086, 273, 4, 34, "Output",ExpressionUUID->"2cceff19-eb0e-4240-9b8a-2adce32d8068"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37471, 1095, 761, 19, 52, "Input",ExpressionUUID->"f1581284-f66b-4e63-9140-dc5a0a6929d6"],
Cell[38235, 1116, 418, 10, 34, "Output",ExpressionUUID->"5d2c6efe-d519-4f55-a453-395c76007f42"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38690, 1131, 604, 15, 52, "Input",ExpressionUUID->"552f7dce-8143-4e26-b01e-055d0c0b78c0"],
Cell[39297, 1148, 245, 3, 34, "Output",ExpressionUUID->"02b1b581-48d4-4b2d-b8b4-fd976dabc604"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39579, 1156, 803, 20, 52, "Input",ExpressionUUID->"43d822c7-07a9-4faa-b5fd-699131e731b3"],
Cell[40385, 1178, 518, 11, 42, "Message",ExpressionUUID->"5afdbf50-b77b-41c4-9e9d-89f4edd3a0bf"],
Cell[40906, 1191, 490, 13, 51, "Output",ExpressionUUID->"6a4f2996-5718-4189-b250-9530e5976a7b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41433, 1209, 778, 19, 52, "Input",ExpressionUUID->"b9f776c8-fd2c-421a-b35f-7e9aac10e31c"],
Cell[42214, 1230, 317, 4, 34, "Output",ExpressionUUID->"1639182e-e153-4b2d-ab13-97a9f5d217df"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42568, 1239, 730, 19, 52, "Input",ExpressionUUID->"d6ebe9f8-ea18-4dae-95e1-3dc44f3b14bf"],
Cell[43301, 1260, 440, 11, 50, "Output",ExpressionUUID->"9141724f-a65d-4c2d-a43e-1f8a2aa2426a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43778, 1276, 670, 18, 52, "Input",ExpressionUUID->"6904b2dd-93f0-4088-8baa-c2a494ea0720"],
Cell[44451, 1296, 177, 3, 34, "Output",ExpressionUUID->"9cc2e70d-198c-4d4a-97bb-ec29468cbd69"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44665, 1304, 784, 20, 52, "Input",ExpressionUUID->"b447cf95-8fdc-4cb0-95db-3f4c2c121111"],
Cell[45452, 1326, 520, 11, 42, "Message",ExpressionUUID->"25982bcb-2249-42c9-a191-375163b5b05e"],
Cell[45975, 1339, 493, 14, 51, "Output",ExpressionUUID->"17cf824e-672d-4234-a176-b5ee66ae9602"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46505, 1358, 660, 18, 52, "Input",ExpressionUUID->"9afee9ab-9674-4c2c-bf17-9473e721fd1f"],
Cell[47168, 1378, 178, 3, 34, "Output",ExpressionUUID->"01e1c4eb-d88d-40fd-9993-31910b9b3a78"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47383, 1386, 759, 21, 52, "Input",ExpressionUUID->"02a59526-2316-4f3f-9110-f2826745556c"],
Cell[48145, 1409, 424, 11, 34, "Output",ExpressionUUID->"b8ab6446-30ca-4227-aefd-b281e596c314"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48606, 1425, 593, 15, 52, "Input",ExpressionUUID->"52dc2371-8352-42e8-9db9-16a15e8199e7"],
Cell[49202, 1442, 180, 3, 34, "Output",ExpressionUUID->"3ca74e9e-d6e7-444f-9f8d-47ce205ea9be"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49419, 1450, 632, 16, 52, "Input",ExpressionUUID->"a2b5d2cf-0802-45d5-a5e8-1b99607fd014"],
Cell[50054, 1468, 205, 4, 34, "Output",ExpressionUUID->"ca180a8c-27d4-4253-baab-519f33e81515"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50296, 1477, 686, 18, 52, "Input",ExpressionUUID->"201e04e7-456a-4cd4-b1cb-7bf0ac553516"],
Cell[50985, 1497, 203, 4, 34, "Output",ExpressionUUID->"305ece02-43c0-483e-a873-aa1070e6a243"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51225, 1506, 649, 17, 52, "Input",ExpressionUUID->"1f3883f0-2f27-47f4-9ef4-d1ecfc5b65c5"],
Cell[51877, 1525, 204, 4, 34, "Output",ExpressionUUID->"76bf0306-0766-4bf1-8430-cb4e3d1ec376"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[52130, 1535, 253, 4, 58, "Chapter",ExpressionUUID->"648091e2-c01f-4ed8-897d-a7ed0eb6cf75"],
Cell[CellGroupData[{
Cell[52408, 1543, 722, 19, 52, "Input",ExpressionUUID->"f422c591-c203-4f7b-b1a9-725504f5f1ad"],
Cell[53133, 1564, 399, 11, 34, "Output",ExpressionUUID->"ed62a678-178c-4fe1-9d3b-46e19570c991"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53569, 1580, 557, 14, 52, "Input",ExpressionUUID->"a33e90e2-f897-41c3-8c7e-934f0935a3e1"],
Cell[54129, 1596, 158, 3, 34, "Output",ExpressionUUID->"02c7a4b9-fd65-451d-9828-1f5dca1ab29f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54324, 1604, 746, 19, 52, "Input",ExpressionUUID->"687e9145-a006-4f8f-b2d4-95753f7d8a49"],
Cell[55073, 1625, 415, 10, 24, "Message",ExpressionUUID->"bcb08ecf-f4d2-4d10-9d84-3d2b42a45df7"],
Cell[55491, 1637, 428, 11, 34, "Output",ExpressionUUID->"ff050ec6-41a2-4a4b-b1ea-c32a66a383ef"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55956, 1653, 570, 15, 52, "Input",ExpressionUUID->"20626b2b-d0fb-4c7b-885f-7550de1d9fb0"],
Cell[56529, 1670, 180, 3, 34, "Output",ExpressionUUID->"550f9aaf-806d-4490-b704-8d7eeb90d50b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56746, 1678, 833, 21, 52, "Input",ExpressionUUID->"abf8c38c-3265-4fa2-bbed-c2f66882983a"],
Cell[57582, 1701, 466, 12, 50, "Output",ExpressionUUID->"2673f262-a75d-470c-ae9f-12d87884018f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58085, 1718, 740, 19, 52, "Input",ExpressionUUID->"3199586c-b5a1-45f9-adc1-e593ae96359a"],
Cell[58828, 1739, 180, 3, 34, "Output",ExpressionUUID->"e41cd5d2-5dc0-4f56-aede-85b9e4126520"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59045, 1747, 756, 20, 52, "Input",ExpressionUUID->"a71e4b85-e602-4b02-b83a-98d7e839e30e"],
Cell[59804, 1769, 413, 10, 24, "Message",ExpressionUUID->"cd79e6c1-b98d-4900-b8e1-5620beac3b50"],
Cell[60220, 1781, 445, 12, 50, "Output",ExpressionUUID->"ce069587-2d4f-4f2e-877a-d79ef4648820"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60702, 1798, 710, 19, 52, "Input",ExpressionUUID->"8e019a3e-3eb8-43ed-aa1c-a0df059af281"],
Cell[61415, 1819, 178, 3, 34, "Output",ExpressionUUID->"b2d01d86-630a-45ed-bcb9-f322f70a4406"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61630, 1827, 734, 20, 52, "Input",ExpressionUUID->"64a33d2a-4a64-4d2a-ac00-6faecc97d8e7"],
Cell[62367, 1849, 399, 11, 34, "Output",ExpressionUUID->"02d6c65c-01e8-42b6-9f48-d1bc80c34464"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62803, 1865, 593, 15, 52, "Input",ExpressionUUID->"1b9fdf22-c887-473b-864d-9980ada5102f"],
Cell[63399, 1882, 156, 3, 34, "Output",ExpressionUUID->"2d63de29-3a6f-409f-a36d-669a26510400"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63592, 1890, 736, 20, 52, "Input",ExpressionUUID->"d373848f-5d51-4f05-8911-61ef6a03607d"],
Cell[64331, 1912, 414, 10, 24, "Message",ExpressionUUID->"608619d6-1284-4768-95c4-cb8747a05924"],
Cell[64748, 1924, 428, 11, 34, "Output",ExpressionUUID->"35bd4055-587d-4aed-8a95-76f1db7b4a93"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65213, 1940, 633, 18, 52, "Input",ExpressionUUID->"9ce22adb-5f16-478b-a29f-b2ec3da33e79"],
Cell[65849, 1960, 156, 3, 34, "Output",ExpressionUUID->"37f96d83-993a-4380-9489-2a74ecf81188"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66042, 1968, 704, 19, 52, "Input",ExpressionUUID->"25866e31-86d8-4fd1-bd9b-b5205d61d02d"],
Cell[66749, 1989, 404, 11, 34, "Output",ExpressionUUID->"9b13e5af-a141-49a5-8313-3c201ed13d21"]
}, Open  ]],
Cell[CellGroupData[{
Cell[67190, 2005, 570, 15, 52, "Input",ExpressionUUID->"f4e4a7a2-e363-4479-a222-a91d31df2350"],
Cell[67763, 2022, 156, 3, 34, "Output",ExpressionUUID->"150820d1-7ee2-41ce-8d36-526278ba025a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[67956, 2030, 600, 16, 52, "Input",ExpressionUUID->"598acdce-90f8-43c4-b0e9-fe26fa5543a4"],
Cell[68559, 2048, 207, 4, 34, "Output",ExpressionUUID->"7d4b42bf-0b8e-4820-938e-ffa811432879"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68803, 2057, 604, 17, 52, "Input",ExpressionUUID->"8642227c-2e0a-4462-9861-a3772606ec16"],
Cell[69410, 2076, 205, 4, 34, "Output",ExpressionUUID->"f888a01c-d811-47ba-b05e-2cbb09b84d04"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[69664, 2086, 312, 5, 58, "Chapter",ExpressionUUID->"67668c2d-b754-46c1-8f1b-0589448f620e"],
Cell[CellGroupData[{
Cell[70001, 2095, 733, 20, 52, "Input",ExpressionUUID->"2f676007-bb6a-4b20-b5c3-201a43d567e9"],
Cell[70737, 2117, 449, 10, 42, "Message",ExpressionUUID->"0b8d649b-e483-4ebf-9657-57815681b605"],
Cell[71189, 2129, 498, 14, 50, "Output",ExpressionUUID->"44331ef2-5bb0-4005-a4cf-cec3ee4a4be9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71724, 2148, 607, 17, 52, "Input",ExpressionUUID->"7e5227c4-d342-4498-bb7e-09b8acc723c6"],
Cell[72334, 2167, 180, 3, 34, "Output",ExpressionUUID->"2531ade1-87ad-4d02-927b-ec7b519d9f63"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72551, 2175, 763, 20, 52, "Input",ExpressionUUID->"9131da45-451a-4517-9634-94ff3811ff4c"],
Cell[73317, 2197, 401, 11, 34, "Output",ExpressionUUID->"0c31dbf0-e9bc-4a2a-a4d3-0773a92738ab"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73755, 2213, 583, 15, 52, "Input",ExpressionUUID->"23ec01ce-4d85-41eb-82b1-019a454b889a"],
Cell[74341, 2230, 178, 3, 34, "Output",ExpressionUUID->"6669cdc3-141e-4155-9965-b15633c8bd2a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74556, 2238, 879, 23, 52, "Input",ExpressionUUID->"21dba3d8-1427-49d4-b896-89ed8d5143de"],
Cell[75438, 2263, 412, 10, 24, "Message",ExpressionUUID->"e228f145-cdac-4fe8-a985-22605ffc3f21"],
Cell[75853, 2275, 423, 11, 34, "Output",ExpressionUUID->"174ad347-4471-42e5-aa26-15dfc92568a1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76313, 2291, 662, 18, 52, "Input",ExpressionUUID->"edf90c57-f00b-4148-9918-00062415b111"],
Cell[76978, 2311, 178, 3, 34, "Output",ExpressionUUID->"af197b48-bf21-4fde-9e05-9e3aad7d1f78"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77193, 2319, 776, 22, 52, "Input",ExpressionUUID->"47a23dc1-d78b-407e-b07f-5e462e217e11"],
Cell[77972, 2343, 402, 11, 34, "Output",ExpressionUUID->"fbe15355-9a5d-4f20-bcf9-ef737e376e55"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78411, 2359, 942, 26, 52, "Input",ExpressionUUID->"da3801e0-9a53-4665-a325-a4e645a6a14e"],
Cell[79356, 2387, 422, 12, 50, "Output",ExpressionUUID->"6a96d870-9247-472a-ac2b-e35d65875cea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79815, 2404, 852, 25, 52, "Input",ExpressionUUID->"d4479e9e-01d2-4384-a281-aa2057310bb3"],
Cell[80670, 2431, 178, 3, 34, "Output",ExpressionUUID->"3a0e3c63-e4e4-4542-83bc-c17143086e71"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80885, 2439, 944, 26, 52, "Input",ExpressionUUID->"19a437d5-16f7-4221-a83f-98b42a334c96"],
Cell[81832, 2467, 412, 10, 24, "Message",ExpressionUUID->"3da898c0-43e3-4f19-b4ae-526ec8b0e5bb"],
Cell[82247, 2479, 446, 12, 50, "Output",ExpressionUUID->"271bc887-43a2-44b7-8e4c-12fd8c9f1d7b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82730, 2496, 796, 23, 52, "Input",ExpressionUUID->"bcb9d77e-1bdb-4f99-8588-f749ca1e27c5"],
Cell[83529, 2521, 178, 3, 34, "Output",ExpressionUUID->"949230d9-e262-4d7f-a071-bbd949f8f957"]
}, Open  ]]
}, Closed]]
}
]
*)

